@@ -2,6 +2,7 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
+import os
 import sys
 import code
 import string
@@ -280,7 +281,10 @@ class Shell(Command):
         if not no_ipython:
             try:
                 import IPython
-                sh = IPython.Shell.IPShellEmbed(banner=self.banner)
+                try:
+                    sh = IPython.Shell.IPShellEmbed(banner=self.banner)
+                except AttributeError:
+                    sh = IPython.frontend.terminal.embed.InteractiveShellEmbed(banner1=self.banner)
                 sh(global_ns=dict(), local_ns=context)
                 return
             except ImportError:
@@ -405,7 +409,7 @@ class Manager(object):
                                   by default.
     """
 
-    def __init__(self, app, with_default_commands=True):
+    def __init__(self, app, with_default_commands=True, usage=None):
 
         self.app = app
 
@@ -415,6 +419,8 @@ class Manager(object):
         if with_default_commands:
             self.add_default_commands()
 
+        self.usage = usage
+
     def add_default_commands(self):
         """
         Adds the shell and runserver default commands. To override these 
@@ -438,6 +444,7 @@ class Manager(object):
         by get_options(), and a subparser for the given command.
         """
 
+        prog = os.path.basename(prog)
         parser = argparse.ArgumentParser(prog=prog)
         for option in self.get_options():
             parser.add_argument(*option.args, **option.kwargs)
@@ -604,6 +611,9 @@ class Manager(object):
 
         rv = []
 
+        if self.usage:
+            rv.append(self.usage)
+
         for name, command in self._commands.iteritems():
             usage = name
             description = command.description or ''
@@ -671,24 +681,19 @@ class Manager(object):
             self._commands.update(commands)
 
         try:
-            if len(sys.argv) == 1 and default_command is not None:
-                command = default_command
-            else:
+
+            try:
                 command = sys.argv[1]
+            except IndexError:
+                command = default_command
 
             if command is None:
                 raise InvalidCommand, "Please provide a command"
 
-            self.handle(sys.argv[0],
-                        command,
-                        sys.argv[2:])
+            self.handle(sys.argv[0], command, sys.argv[2:])
             
             sys.exit(0)
-
-        except IndexError:
-            self.print_usage()
-            sys.exit(0)
-        
+       
         except InvalidCommand, e:
             print e
             self.print_usage()
