@@ -253,6 +253,15 @@ class TestManager(unittest.TestCase):
 
         assert "simple     simple command" in manager.get_usage()
 
+    def test_get_usage_with_specified_usage(self):
+
+        manager = Manager(self.app, usage="hello")
+        manager.add_command("simple", SimpleCommand())
+
+        usage = manager.get_usage()
+        assert "simple     simple command" in usage
+        assert "hello" in usage
+
     def test_run_existing_command(self):
         
         manager = Manager(self.app)
@@ -305,7 +314,7 @@ class TestManager(unittest.TestCase):
         try:
             manager.run()
         except SystemExit, e:
-            assert e.code == 0
+            assert e.code == 1
 
     def test_run_good_options(self):
 
@@ -359,6 +368,20 @@ class TestManager(unittest.TestCase):
         manager = Manager(lambda: app)
         assert callable(manager.app)
 
+    def test_raise_index_error(self):
+
+        manager = Manager(self.app)
+        
+        @manager.command
+        def error():
+            raise IndexError()
+
+        try:
+            self.assertRaises(IndexError, manager.run, default_command="error")
+        except SystemExit, e:
+            assert e.code == 1  
+
+
     def test_run_with_default_command(self):
         manager = Manager(self.app)
         manager.add_command('simple', SimpleCommand())
